@@ -1,4 +1,4 @@
-import os
+import sys, os
 
 from mlflow.tracking import MlflowClient
 import mlflow.pyfunc
@@ -30,7 +30,7 @@ import logging
 from .config import p as cfg
 from .basehandler import BaseHandler
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 class Server:
 
@@ -75,9 +75,9 @@ class Server:
             if self.app.openapi_schema:
                 return self.app.openapi_schema
             openapi_schema = get_openapi(
-                title="MLflow PyFunc Server",
+                title=self.config.title,
                 version=__version__,
-                description="Serve MLflow PyFunc models",
+                description=self.config.description,
                 routes=self.app.routes,
             )
             self.app.openapi_schema = openapi_schema
@@ -189,7 +189,15 @@ class Server:
             if "server" in self.error_dict:
                 del self.error_dict["server"]
         except Exception as ex:
-            self.error_dict["server"] = str(ex)
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            self.error_dict["server"] = {
+                "message": str(ex),
+                "type": str(exc_type),
+                "file": fname,
+                "line": exc_tb.tb_lineno,
+                "exception": exc_obj
+            }
 
         for m in all_models:
 
@@ -221,7 +229,16 @@ class Server:
                 if name in self.error_dict:
                     del self.error_dict[name]
             except Exception as ex:
-                self.error_dict["name"] = str(ex)
+                exc_type, exc_obj, exc_tb = sys.exc_info()
+                fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+                self.error_dict[name] = {
+                    "message": str(ex),
+                    "type": str(exc_type),
+                    "file": fname,
+                    "line": exc_tb.tb_lineno,
+                    "exception": exc_obj
+                }
+
 
         self.app.openapi_schema = None
 
